@@ -9,5 +9,9 @@
 import shutil
 
 
-def create_zip_file(output_full_path, input_dir):
+def zip_file(output_full_path, input_dir):
     shutil.make_archive(output_full_path, 'zip', input_dir)
+
+
+def unzip_file(filename, dest_dir=None, fmt=None):
+    shutil.unpack_archive(filename, dest_dir, fmt)
